macro_rules! bug {
($msg:literal) => { ... };
}Expand description
Panics with the given message in debug mode or logs an error otherwise.
macro_rules! bug {
($msg:literal) => { ... };
}Panics with the given message in debug mode or logs an error otherwise.